==> igniteui-react-charts-16.6.4.tgz: package/ES5/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Style } from "igniteui-react-core/ES5/Style";
import { Type, markType, typeCast } from "igniteui-react-core/ES5/type";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { Path } from "igniteui-react-core/ES5/Path";
import { stringIsNullOrEmpty } from "igniteui-react-core/ES5/string";
var ScatterPolylineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(ScatterPolylineSeries, _super);
    function ScatterPolylineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterPolylineSeries.$;
        return _this;
    }
    ScatterPolylineSeries.prototype.bf = function () {
        return new ScatterPolylineSeriesView(this);
    };
    ScatterPolylineSeries.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.mz = a;
    };
    ScatterPolylineSeries.prototype.get_l6 = function () {
        return false;
    };
    ScatterPolylineSeries.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case ScatterPolylineSeries.$$p[0]:
                this.mz.cn(this.m5);
                this.i4(false);
                this.ib();
                break;
            case ScatterPolylineSeries.$$p[1]:
                this.mz.co(this.m0);
                this.i4(false);
                this.ib();
                break;
        }
    };
    ScatterPolylineSeries.prototype.mp = function (a) {
        var b = a;
        b.cn(this.m5);
        b.co(this.m0);
        _super.prototype.mp.call(this, a);
    };
    ScatterPolylineSeries.prototype.ar = function (a, b) {
        var c = this.mz.cs(a, b, true);
        if (c != null) {
            return c.dataContext;
        }
        return _super.prototype.ar.call(this, a, b);
    };
    ScatterPolylineSeries.$t = markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
    return ScatterPolylineSeries;
}(ShapeSeriesBase));
export { ScatterPolylineSeries };
Type.dep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:m5:m3', [Style.$, null], 'ShapeStyleSelector:m0:m4', [StyleSelector.$, null]]);
var ScatterPolylineSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(ScatterPolylineSeriesView, _super);
    function ScatterPolylineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    ScatterPolylineSeriesView.prototype.cu = function (a, b) {
        return this.cv(a, b, false);
    };
    ScatterPolylineSeriesView.prototype.cc = function (a, b) {
        _super.prototype.cc.call(this, a, b);
        ShapeSeriesViewBase.cb(this, a, b);
    };
    ScatterPolylineSeriesView.prototype.ca = function (a, b) {
        var c = typeCast(Path.$, a);
        if (c == null) {
            return;
        }
        c.aj = b;
    };
    ScatterPolylineSeriesView.prototype.bb = function (a, b) {
        _super.prototype.bb.call(this, a, b);
        var c = a;
        c._fill = null;
    };
    ScatterPolylineSeriesView.prototype.bc = function (a, b) {
        _super.prototype.bc.call(this, a, b);
        var c = a;
        c._fill = null;
    };
    ScatterPolylineSeriesView.prototype.b2 = function (a) {
        return a.width >= this.by.mf || a.height >= this.by.mf;
    };
    ScatterPolylineSeriesView.prototype.getDefaultTooltipTemplate = function () {
        var a = "<div class='ui-chart-default-tooltip-content'><span";
        var b = this.e.a0.a$q(this.e);
        if (!stringIsNullOrEmpty(b)) {
            a += " style='color:" + b + "'";
        }
        a += ">" + this.by.fr + "</span><br/>";
        a += "</div>";
        return a;
    };
    ScatterPolylineSeriesView.$t = markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);
    return ScatterPolylineSeriesView;
}(ShapeSeriesViewBase));
export { ScatterPolylineSeriesView };

==> igniteui-react-charts-16.6.7.tgz: package/ES5/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Style } from "igniteui-react-core/ES5/Style";
import { Type, markType, typeCast } from "igniteui-react-core/ES5/type";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { Path } from "igniteui-react-core/ES5/Path";
import { stringIsNullOrEmpty } from "igniteui-react-core/ES5/string";
/**
 * @hidden
 */
var ScatterPolylineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(ScatterPolylineSeries, _super);
    function ScatterPolylineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterPolylineSeries.$;
        return _this;
    }
    ScatterPolylineSeries.prototype.bf = function () {
        return new ScatterPolylineSeriesView(this);
    };
    ScatterPolylineSeries.prototype.im = function (a) {
        _super.prototype.im.call(this, a);
        this.m1 = a;
    };
    ScatterPolylineSeries.prototype.get_l8 = function () {
        return false;
    };
    ScatterPolylineSeries.prototype.is = function (a, b, c, d) {
        _super.prototype.is.call(this, a, b, c, d);
        switch (b) {
            case ScatterPolylineSeries.$$p[0]:
                this.m1.cn(this.m7);
                this.i6(false);
                this.ic();
                break;
            case ScatterPolylineSeries.$$p[1]:
                this.m1.co(this.m2);
                this.i6(false);
                this.ic();
                break;
        }
    };
    ScatterPolylineSeries.prototype.mr = function (a) {
        var b = a;
        b.cn(this.m7);
        b.co(this.m2);
        _super.prototype.mr.call(this, a);
    };
    ScatterPolylineSeries.prototype.ar = function (a, b) {
        var c = this.m1.cs(a, b, true);
        if (c != null) {
            return c.dataContext;
        }
        return _super.prototype.ar.call(this, a, b);
    };
    ScatterPolylineSeries.$t = markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
    return ScatterPolylineSeries;
}(ShapeSeriesBase));
export { ScatterPolylineSeries };
Type.dep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:m7:m5', [Style.$, null], 'ShapeStyleSelector:m2:m6', [StyleSelector.$, null]]);
/**
 * @hidden
 */
var ScatterPolylineSeriesView = /** @class */ (function (_super) {
    tslib_1.__extends(ScatterPolylineSeriesView, _super);
    function ScatterPolylineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    ScatterPolylineSeriesView.prototype.cu = function (a, b) {
        return this.cv(a, b, false);
    };
    ScatterPolylineSeriesView.prototype.cc = function (a, b) {
        _super.prototype.cc.call(this, a, b);
        ShapeSeriesViewBase.cb(this, a, b);
    };
    ScatterPolylineSeriesView.prototype.ca = function (a, b) {
        var c = typeCast(Path.$, a);
        if (c == null) {
            return;
        }
        c.aj = b;
    };
    ScatterPolylineSeriesView.prototype.bb = function (a, b) {
        _super.prototype.bb.call(this, a, b);
        var c = a;
        c._fill = null;
    };
    ScatterPolylineSeriesView.prototype.bc = function (a, b) {
        _super.prototype.bc.call(this, a, b);
        var c = a;
        c._fill = null;
    };
    ScatterPolylineSeriesView.prototype.b2 = function (a) {
        return a.width >= this.by.mh || a.height >= this.by.mh;
    };
    ScatterPolylineSeriesView.prototype.getDefaultTooltipTemplate = function () {
        var a = "<div class='ui-chart-default-tooltip-content'><span";
        var b = this.e.a0.a$q(this.e);
        if (!stringIsNullOrEmpty(b)) {
            a += " style='color:" + b + "'";
        }
        a += ">" + this.by.fs + "</span><br/>";
        a += "</div>";
        return a;
    };
    ScatterPolylineSeriesView.$t = markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);
    return ScatterPolylineSeriesView;
}(ShapeSeriesViewBase));
export { ScatterPolylineSeriesView };
